@@ -1,14 +1,14 @@
 from .cache_condition import NOT_NONE  # noqa
 from .commands import Command  # noqa
-from .decorators import context_cache_detect, fast_condition  # noqa
+from .contrib import *  # noqa
+from .decorators import context_cache_detect, fast_condition, thunder_protection  # noqa
 from .exceptions import CacheBackendInteractionError, CircuitBreakerOpen, LockedError, RateLimitError  # noqa
 from .formatter import default_formatter, get_template_and_func_for, get_template_for_key  # noqa
 from .helpers import add_prefix, all_keys_lower, memory_limit  # noqa
-from .key import noself  # noqa
+from .key import get_cache_key_template, noself  # noqa
 from .validation import invalidate_further  # noqa
-from .wrapper import Cache, register_backend  # noqa
+from .wrapper import Cache, TransactionMode, register_backend  # noqa
 
-cache_detect = context_cache_detect
 # pylint: disable=invalid-name
 cache = Cache(name="default")
 noself_cache = noself(cache.cache)
@@ -16,6 +16,9 @@ failover = cache.failover
 early = cache.early
 soft = cache.soft
 hit = cache.hit
+transaction = cache.transaction
+setup = cache.setup
+cache_detect = cache.detect
 
 circuit_breaker = cache.circuit_breaker
 dynamic = cache.dynamic
