@@ -1,5 +1,5 @@
 from datetime import timedelta
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, Tuple, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, Iterable, Tuple, Type, TypeVar, Union
 
 try:
     from typing import Protocol
@@ -15,6 +15,14 @@ class CallableCacheCondition(Protocol):
         ...
 
 
+Key = str
+KeyTemplate = str
+KeyOrTemplate = Union[KeyTemplate, Key]
+Value = Any
+Tag = str
+Tags = Iterable[Tag]
+Exceptions = Union[Type[Exception], Iterable[Type[Exception]], None]
+
 CacheCondition = Union[CallableCacheCondition, str, None]
 
 AsyncCallableResult_T = TypeVar("AsyncCallableResult_T")
@@ -36,3 +44,12 @@ class Middleware(Protocol):
         **kwargs,
     ) -> Awaitable[AsyncCallableResult_T]:  # pragma: no cover
         ...
+
+
+class Callback(Protocol):
+    def __call__(
+        self,
+        keys: Iterable[Key],
+        backend: "Backend",
+    ) -> Awaitable:  # pragma: no cover
+        ...
