@@ -5,9 +5,10 @@ from .cache.defaults import CacheDetect, context_cache_detect  # noqa
 from .cache.early import early  # noqa
 from .cache.fail import failover, fast_condition  # noqa
 from .cache.hit import hit  # noqa
+from .cache.iterator import iterator  # noqa
 from .cache.simple import cache  # noqa
 from .cache.soft import soft  # noqa
 from .circuit_breaker import circuit_breaker  # noqa
-from .locked import locked  # noqa
+from .locked import locked, thunder_protection  # noqa
 from .rate import rate_limit  # noqa
 from .rate_slide import slice_rate_limit  # noqa
