@@ -2,10 +2,9 @@ import logging
 from functools import wraps
 from typing import Any, Callable, NoReturn, Optional
 
-from cashews._typing import TTL, AsyncCallable_T, Decorator
+from cashews._typing import TTL, AsyncCallable_T, Decorator, KeyOrTemplate
 from cashews.backends.interface import _BackendInterface
 from cashews.exceptions import RateLimitError
-from cashews.formatter import register_template
 from cashews.key import get_cache_key, get_cache_key_template
 from cashews.ttl import ttl_to_seconds
 
@@ -21,7 +20,7 @@ def rate_limit(
     limit: int,
     period: TTL,
     ttl: Optional[TTL] = None,
-    key: Optional[str] = None,
+    key: Optional[KeyOrTemplate] = None,
     action: Callable = _default_action,
     prefix: str = "rate_limit",
 ) -> Decorator:  # pylint: disable=too-many-arguments
@@ -42,7 +41,6 @@ def rate_limit(
 
     def decorator(func: AsyncCallable_T) -> AsyncCallable_T:
         _key_template = get_cache_key_template(func, key=key, prefix=prefix)
-        register_template(func, _key_template)
 
         @wraps(func)
         async def wrapped_func(*args, **kwargs):
@@ -50,16 +48,12 @@ def rate_limit(
             _period = ttl_to_seconds(period, *args, **kwargs, with_callable=True)
             _cache_key = get_cache_key(func, _key_template, args, kwargs)
 
-            requests_count = await backend.incr(key=_cache_key)  # set 1 if not exists
+            requests_count = await backend.incr(key=_cache_key, expire=_period)
             if requests_count and requests_count > limit:
                 if ttl and requests_count == limit + 1:
                     await backend.expire(key=_cache_key, timeout=_ttl)
                 logger.info("Rate limit reach for %s", _cache_key)
                 action(*args, **kwargs)
-
-            if requests_count == 1:
-                await backend.expire(key=_cache_key, timeout=_period)
-
             return await func(*args, **kwargs)
 
         return wrapped_func
